#ifndef PROFILE_VIEWER_H
#define PROFILE_VIEWER_H

#include <glib.h>
#include <tangle.h>

typedef struct{

	guint32 user_id;
	char parent_view[30];

}profile_view_params;

void start_profile_view(profile_view_params*);
gboolean end_profile_view(TangleActor* actor, gpointer data);

#endif
